<?php

namespace Classifieds\Ad\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Classifieds\Ad\Actions\AdAction;
use Classifieds\Ad\Http\Requests\AdActionRequest;
use Classifieds\Ad\Http\Resources\AdResource;
use Classifieds\Ad\Models\Ad;

/**
 * Admin web controller class.
 */
class AdActionController extends BaseController
{

    /**
     * Action controller function for ad.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(AdActionRequest $request, Ad $ad, $action)
    {
        try {
            $request = $request->all();
            $ad = AdAction::run($action, $ad, $request);

            $data = new AdResource($ad);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('ad::ad.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('ad/ad/' . $ad->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('ad/ad/' . $ad->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
