<?php

namespace Classifieds\Ad\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Classifieds\Ad\Http\Resources\AdResource;
use Classifieds\Ad\Http\Resources\AdsCollection;
use Classifieds\Ad\Scopes\AdPublicScope;
use Classifieds\Ad\Models\Ad;

class AdPublicController extends BaseController
{

    /**
     * Show ad's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Ad::pushScope(new RequestScope())
            ->pushScope(new AdPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $ads = new AdsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('ad::ad.names'))
            ->view('ad::public.ad.index')
            ->data(compact('ads', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show ad.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Ad::findBySlug($slug);
        $data = new AdResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('ad::ad.name'))
            ->view('ad::public.ad.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
