<?php

namespace Classifieds\Ad\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Classifieds\Ad\Events\AdAction as AdActionEvent;
use Classifieds\Ad\Notifications\AdAction as AdActionNotification;
use Litepie\Actions\Concerns\AsAction;

class AdAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the AdActionEvent.
     *
     * @param   AdActionEvent  $event
     * @return mixed
     */
    public function handle(AdActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $ad.
     *
     * @param   AdActionEvent  $event
     * @return void
     */
    public function create(AdActionEvent $event)
    {
        $client = $event->ad->client;
        Notification::send($client, new AdActionNotification($event));
    }

    /**
     * Handle the AdActionEvent as a listener.
     *
     * @param   AdActionEvent  $event
     * @return mixed
     */
    public function asListener(AdActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   AdActionEvent  $event
     * @return bool
     */
    private function isAllowed(AdActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
