<?php
namespace Classifieds\Ad\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Classifieds\Ad\Events\AdAction as AdActionEvent;
use Classifieds\Ad\Models\Ad;

class AdAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $ad;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AdActionEvent $ad
     */
    public function __construct(AdActionEvent $ad)
    {
        $this->action = $event->action;
        $this->ad = $ad;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Ad Approved - ' . config('app.name'))
            ->view('ad::ad.email.action', ['data' => $this->ad]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
