<?php

namespace Classifieds\Ad\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Classifieds\Ad\Models\Ad;

class AdPolicy
{

    use AdAction;
    use AdWorkflow;

    /**
     * Determine if the given user can view the ad.
     *
     * @param Authenticatable $user
     * @param Ad $ad
     *
     * @return bool
     */
    public function view(Authenticatable $user, Ad $ad)
    {
        if ($authUser->canDo('ad.ad.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $ad->is_owner;
    }

    /**
     * Determine if the given user can create a ad.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('ad.ad.create');
    }

    /**
     * Determine if the given user can update the given ad.
     *
     * @param Authenticatable $user
     * @param Ad $ad
     *
     * @return bool
     */
    public function update(Authenticatable $user, Ad $ad)
    {
        if ($user->canDo('ad.ad.edit') && $user->isAdmin()) {
            return true;
        }

        return $ad->is_owner;
    }

    /**
     * Determine if the given user can delete the given ad.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Ad $ad)
    {
        return $ad->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
